summaryrefslogtreecommitdiff
path: root/test/CubeView.h
diff options
context:
space:
mode:
Diffstat (limited to 'test/CubeView.h')
-rw-r--r--test/CubeView.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/CubeView.h b/test/CubeView.h
index 67424d3bb..9568e93c9 100644
--- a/test/CubeView.h
+++ b/test/CubeView.h
@@ -81,13 +81,13 @@ public:
void pany(double y) { yshift = y; }
#if HAVE_GL
/* The widget class draw() override.
*
* The draw() function initializes Gl for another round of
* drawing, then calls specialized functions for drawing each
* of the entities displayed in the cube view.
*/
- void draw();
+ void draw() FL_OVERRIDE;
#endif /* HAVE_GL */
private:
@@ -81,13 +81,13 @@ public:
void pany(double y) { yshift = y; }
#if HAVE_GL
- /* The widget class draw() override.
+ /* The widget class draw() FL_OVERRIDE.
*
* The draw() function initializes Gl for another round of